@@ -42,6 +42,8 @@ var (
 	ver bool
 	// helpKey is key bind information.
 	helpKey bool
+	// listViewMode is list view mode.
+	listViewMode bool
 	// completion is the generation of shell completion.
 	completion string
 	// execCommand targets the output of executing the command.
@@ -49,11 +51,6 @@ var (
 
 	// forceScreen is display screen even when redirecting output.
 	forceScreen bool
-
-	// alignF is align column.
-	alignF bool
-	// rawF is raw output of escape sequences.
-	rawF bool
 )
 
 var (
@@ -91,32 +88,14 @@ It supports various compressed files(gzip, bzip2, zstd, lz4, and xz).
 			HelpKey(cmd, args)
 			return nil
 		}
+		if listViewMode {
+			ListViewMode()
+			return nil
+		}
 
 		if completion != "" {
 			return Completion(cmd, completion)
 		}
-		// Set the caption from the environment variable.
-		if config.General.Caption == "" {
-			config.General.Caption = viper.GetString("CAPTION")
-		}
-
-		// Actually tabs when "\t" is specified as an option.
-		if config.General.ColumnDelimiter == "\\t" {
-			config.General.ColumnDelimiter = "\t"
-		}
-
-		// SectionHeader is enabled if SectionHeaderNum is greater than 0.
-		if config.General.SectionHeaderNum > 0 {
-			config.General.SectionHeader = true
-		}
-
-		// Set a converter by specifying flag.
-		if alignF {
-			config.General.Converter = "align"
-		} else if rawF {
-			config.General.Converter = "raw"
-		}
-
 		// Set a global variable to convert to a style before opening the file.
 		oviewer.OverStrikeStyle = oviewer.ToTcellStyle(config.StyleOverStrike)
 		oviewer.OverLineStyle = oviewer.ToTcellStyle(config.StyleOverLine)
@@ -143,6 +122,14 @@ func HelpKey(cmd *cobra.Command, _ []string) {
 	fmt.Print(oviewer.DuplicateKeyBind(keyBind))
 }
 
+// ListViewMode displays the list of view modes.
+func ListViewMode() {
+	listView := oviewer.ListViewMode(config)
+	for _, v := range listView {
+		fmt.Println(v)
+	}
+}
+
 // Completion is shell completion.
 func Completion(cmd *cobra.Command, arg string) error {
 	switch arg {
@@ -202,20 +189,15 @@ func RunOviewer(args []string) error {
 		ov.Filter(nonMatchFilter, true)
 	}
 
-	if ov.QuitSmall && (filter != "" || nonMatchFilter != "") {
-		ov.QuitSmallFilter = true
+	if ov.Config.QuitSmall && (filter != "" || nonMatchFilter != "") {
+		ov.Config.QuitSmallFilter = true
 	}
 	// Run oviewer.
 	if err := ov.Run(); err != nil {
 		return err
 	}
 
-	if ov.IsWriteOriginal {
-		ov.WriteOriginal()
-	}
-	if ov.Debug {
-		ov.WriteLog()
-	}
+	ov.OutputOnExit()
 	return nil
 }
 
@@ -240,12 +222,8 @@ func ExecCommand(args []string) error {
 		return err
 	}
 
-	if ov.IsWriteOriginal {
-		ov.WriteOriginal()
-	}
-	if ov.Debug {
-		ov.WriteLog()
-	}
+	ov.OutputOnExit()
+
 	return nil
 }
 
@@ -403,6 +381,8 @@ func init() {
 	})
 	rootCmd.PersistentFlags().BoolVarP(&ver, "version", "v", false, "display version information")
 	rootCmd.PersistentFlags().BoolVarP(&helpKey, "help-key", "", false, "display key bind information")
+	rootCmd.PersistentFlags().BoolVarP(&listViewMode, "list-view-modes", "", false, "list available view modes defined in the configuration file")
+
 	rootCmd.PersistentFlags().BoolVarP(&execCommand, "exec", "e", false, "command execution result instead of file")
 
 	rootCmd.PersistentFlags().BoolVarP(&forceScreen, "force-screen", "", false, "display screen even when redirecting output")
@@ -417,9 +397,6 @@ func init() {
 	rootCmd.PersistentFlags().StringVarP(&nonMatchFilter, "non-match-filter", "", "", "filter non match search pattern")
 	rootCmd.PersistentFlags().BoolVarP(&oviewer.SkipExtract, "skip-extract", "", false, "skip extracting compressed files")
 
-	rootCmd.PersistentFlags().BoolVarP(&alignF, "align", "l", false, "align the output columns for better readability")
-	rootCmd.PersistentFlags().BoolVarP(&rawF, "raw", "r", false, "raw escape sequences without processing")
-
 	// Config.General
 	rootCmd.PersistentFlags().StringP("converter", "", "es", "converter [es|raw|align]")
 	_ = viper.BindPFlag("general.Converter", rootCmd.PersistentFlags().Lookup("converter"))
@@ -427,6 +404,11 @@ func init() {
 		return []string{"es\tEscape Sequence", "raw\tRaw output of escape sequences", "align\tAlign Column Widths"}, cobra.ShellCompDirectiveNoFileComp
 	})
 
+	rootCmd.PersistentFlags().BoolP("align", "l", false, "align the output columns for better readability")
+	_ = viper.BindPFlag("general.Align", rootCmd.PersistentFlags().Lookup("align"))
+	rootCmd.PersistentFlags().BoolP("raw", "r", false, "raw escape sequences without processing")
+	_ = viper.BindPFlag("general.Raw", rootCmd.PersistentFlags().Lookup("raw"))
+
 	rootCmd.PersistentFlags().IntP("tab-width", "x", 8, "tab stop width")
 	_ = viper.BindPFlag("general.TabWidth", rootCmd.PersistentFlags().Lookup("tab-width"))
 	_ = rootCmd.RegisterFlagCompletionFunc("tab-width", func(_ *cobra.Command, _ []string, _ string) ([]string, cobra.ShellCompDirective) {
@@ -542,7 +524,7 @@ func init() {
 	_ = viper.BindPFlag("QuitSmall", rootCmd.PersistentFlags().Lookup("quit-if-one-screen"))
 
 	rootCmd.PersistentFlags().BoolP("exit-write", "X", false, "output the current screen when exiting")
-	_ = viper.BindPFlag("IsWriteOriginal", rootCmd.PersistentFlags().Lookup("exit-write"))
+	_ = viper.BindPFlag("IsWriteOnExit", rootCmd.PersistentFlags().Lookup("exit-write"))
 
 	rootCmd.PersistentFlags().IntP("exit-write-before", "b", 0, "number before the current lines when exiting")
 	_ = viper.BindPFlag("BeforeWriteOriginal", rootCmd.PersistentFlags().Lookup("exit-write-before"))
@@ -574,7 +556,7 @@ func init() {
 	rootCmd.PersistentFlags().BoolP("disable-column-cycle", "", false, "disable column cycling")
 	_ = viper.BindPFlag("DisableColumnCycle", rootCmd.PersistentFlags().Lookup("disable-column-cycle"))
 
-	rootCmd.PersistentFlags().StringP("view-mode", "", "", "apply predefined settings for a specific mode")
+	rootCmd.PersistentFlags().StringP("view-mode", "m", "", "apply predefined settings for a specific mode")
 	_ = viper.BindPFlag("ViewMode", rootCmd.PersistentFlags().Lookup("view-mode"))
 
 	rootCmd.PersistentFlags().BoolP("debug", "", false, "debug mode")
