@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"io"
 	"io/fs"
+	"log"
 	"os"
 	"regexp"
 	"sync"
@@ -260,7 +261,7 @@ func NewDocument() (*Document, error) {
 		return nil, err
 	}
 	m.alignConv = newAlignConverter(m.ColumnWidth)
-	m.conv = m.converterType(m.RunTimeSettings.Converter)
+	m.conv = m.converterType(m.Converter)
 
 	m.cond = sync.NewCond(&sync.Mutex{})
 	return m, nil
@@ -468,6 +469,29 @@ func (m *Document) WaitEOF() {
 	m.cond.Wait()
 }
 
+// WaitEOFWithTimeout waits for EOF with a timeout.
+// Parameters:
+// - timeout: the duration to wait before timing out.
+func (m *Document) WaitEOFWithTimeout(timeout time.Duration) {
+	if m.BufEOF() {
+		return
+	}
+
+	doneCh := make(chan struct{})
+	go func() {
+		m.cond.L.Lock()
+		defer m.cond.L.Unlock()
+		m.cond.Wait()
+		doneCh <- struct{}{}
+	}()
+
+	select {
+	case <-doneCh:
+	case <-time.After(timeout):
+		log.Println("WaitEOFWithTimeout timed out")
+	}
+}
+
 // BufEOF checks if the end of the file (EOF) has been reached in the document buffer.
 // Returns:
 // - A boolean value: true if EOF is reached, false otherwise.
