@@ -155,16 +155,29 @@ func (root *Root) copyToClipboard(_ context.Context) {
 		root.debugMessage("copyToClipboard: " + err.Error())
 		return
 	}
-
 	if len(str) == 0 {
 		return
 	}
-	if err := clipboard.WriteAll(str); err != nil {
-		log.Printf("copyToClipboard: %v", err)
-	}
+
+	root.copyClipboard(str)
 	root.setMessage("Copy")
 }
 
+// copyClipboard copies the string to the clipboard.
+// The method of copying to the clipboard is determined by the configuration.
+// The default method is to use the clipboard package.
+// "OSC52” can be specified (available only if the terminal supports it).
+func (root *Root) copyClipboard(str string) {
+	switch root.Config.ClipboardMethod {
+	case "OSC52":
+		root.Screen.SetClipboard([]byte(str))
+	default:
+		if err := clipboard.WriteAll(str); err != nil {
+			log.Printf("copyToClipboard: %v\n", err)
+		}
+	}
+}
+
 type eventPaste struct {
 	tcell.EventTime
 }
@@ -189,7 +202,7 @@ func (root *Root) pasteFromClipboard(context.Context) {
 
 	str, err := clipboard.ReadAll()
 	if err != nil {
-		log.Printf("pasteFromClipboard: %v", err)
+		log.Printf("pasteFromClipboard: %v\n", err)
 		return
 	}
 
@@ -309,7 +322,7 @@ func (scr SCR) branchWidth(lc contents, branch int) int {
 	i := 0
 	w := scr.startX
 	x := 0
-	for n := 0; n < len(lc); n++ {
+	for n := range lc {
 		c := lc[n]
 		if w+c.width > scr.vWidth {
 			i++
@@ -342,7 +355,7 @@ func (scr SCR) selectLine(lineC LineC, x1 int, x2 int) string {
 	end := lineC.pos.n(x2)
 
 	if start > len(lineC.str) || end > len(lineC.str) || start > end {
-		log.Printf("selectLine:len(%d):start(%d):end(%d)", len(lineC.str), start, end)
+		log.Printf("selectLine:len(%d):start(%d):end(%d)\n", len(lineC.str), start, end)
 		return ""
 	}
 	return lineC.str[start:end]
