@@ -12,9 +12,12 @@ import (
 	"time"
 )
 
-// sectionTimeOut is the section header search timeout(in milliseconds) period.
-const sectionTimeOut time.Duration = 1000
-const rulerHeight = 2
+const (
+	// sectionTimeOut is the section header search timeout(in milliseconds) period.
+	sectionTimeOut time.Duration = 1000
+	// rulerHeight is the height of the ruler.
+	rulerHeight = 2
+)
 
 // prepareScreen prepares when the screen size is changed.
 func (root *Root) prepareScreen() {
@@ -32,7 +35,12 @@ func (root *Root) prepareScreen() {
 	}
 	root.scr.startY = root.scr.rulerHeight
 
-	num := int(math.Round(calculatePosition(root.Doc.HScrollWidth, root.scr.vWidth)))
+	n, err := calculatePosition(root.Doc.HScrollWidth, root.scr.vWidth)
+	if err != nil {
+		root.setMessageLogf("Invalid HScrollWidth: %s", root.Doc.HScrollWidth)
+		n = 0
+	}
+	num := int(math.Round(n))
 	root.Doc.HScrollWidthNum = max(num, 1)
 
 	if len(root.scr.numbers) < root.scr.vHeight+1 {
@@ -170,7 +178,7 @@ func (root *Root) setAlignConverter() {
 	for n := len(m.alignConv.columnAttrs); n < len(maxWidths)+1; n++ {
 		m.alignConv.columnAttrs = append(m.alignConv.columnAttrs, columnAttribute{})
 	}
-	for i := 0; i < len(addRight); i++ {
+	for i := range addRight {
 		if !m.alignConv.columnAttrs[i].rightAlign {
 			m.alignConv.columnAttrs[i].rightAlign = addRight[i] > 1
 		}
@@ -203,7 +211,7 @@ func maxWidthsDelm(lc contents, maxWidths []int, rightCount []int, delimiter str
 	}
 
 	start := pos.x(0)
-	for i := 0; i < len(indexes); i++ {
+	for i := range indexes {
 		end := pos.x(indexes[i][0])
 		delmEnd := pos.x(indexes[i][1])
 		width := end - start
@@ -224,7 +232,7 @@ func maxWidthsWidth(lc contents, maxWidths []int, rightCount []int, widths []int
 		return maxWidths, rightCount
 	}
 	start := 0
-	for i := 0; i < len(widths); i++ {
+	for i := range widths {
 		end := findColumnEnd(lc, widths, i, start) + 1
 		if start > end {
 			break
@@ -269,7 +277,7 @@ func trimWidth(lc contents) (int, int) {
 // trimmedIndices returns the start and end of the trimmed contents.
 func trimmedIndices(lc contents) (int, int) {
 	ts := 0
-	for i := 0; i < len(lc); i++ {
+	for i := range lc {
 		if !lc.IsSpace(i) {
 			ts = i
 			break
@@ -394,7 +402,7 @@ func (root *Root) lineContent(lN int) LineC {
 	if m.ColumnMode {
 		lineC = m.columnRanges(lineC)
 	}
-	RangeStyle(lineC.lc, 0, len(lineC.lc), root.StyleBody)
+	RangeStyle(lineC.lc, 0, len(lineC.lc), m.Style.Body)
 	root.styleContent(lineC)
 	return lineC
 }
@@ -406,7 +414,7 @@ func (root *Root) sectionNum(lines map[int]LineC) map[int]LineC {
 		return lines
 	}
 	if m.SectionDelimiterReg == nil {
-		log.Printf("Regular expression is not set: %s", m.SectionDelimiter)
+		log.Printf("Regular expression is not set: %s\n", m.SectionDelimiter)
 		return lines
 	}
 	lNs := lineNumbers(lines)
@@ -470,7 +478,7 @@ func (root *Root) styleContent(lineC LineC) {
 
 // plainStyle defaults to the original style.
 func (*Root) plainStyle(lc contents) {
-	for x := 0; x < len(lc); x++ {
+	for x := range lc {
 		lc[x].style = defaultStyle
 	}
 }
@@ -483,11 +491,11 @@ func (root *Root) columnHighlight(lineC LineC) {
 // multiColorHighlight applies styles to multiple words (regular expressions) individually.
 // The style of the first specified word takes precedence.
 func (root *Root) multiColorHighlight(lineC LineC) {
-	numC := len(root.StyleMultiColorHighlight)
+	numC := len(root.Doc.Style.MultiColorHighlight)
 	for i := len(root.Doc.multiColorRegexps) - 1; i >= 0; i-- {
 		indexes := searchPositionReg(lineC.str, root.Doc.multiColorRegexps[i])
 		for _, idx := range indexes {
-			RangeStyle(lineC.lc, lineC.pos.x(idx[0]), lineC.pos.x(idx[1]), root.StyleMultiColorHighlight[i%numC])
+			RangeStyle(lineC.lc, lineC.pos.x(idx[0]), lineC.pos.x(idx[1]), root.Doc.Style.MultiColorHighlight[i%numC])
 		}
 	}
 }
@@ -501,7 +509,7 @@ func (root *Root) searchHighlight(lineC LineC) {
 
 	indexes := root.searchPosition(lineC.str)
 	for _, idx := range indexes {
-		RangeStyle(lineC.lc, lineC.pos.x(idx[0]), lineC.pos.x(idx[1]), root.StyleSearchHighlight)
+		RangeStyle(lineC.lc, lineC.pos.x(idx[0]), lineC.pos.x(idx[1]), root.Doc.Style.SearchHighlight)
 	}
 }
 
@@ -524,7 +532,7 @@ func (m Document) columnDelimiterRange(lineC LineC) []columnRange {
 
 	var columnRanges []columnRange
 	start := lineC.pos.x(0)
-	for columnNum := 0; columnNum < len(indexes); columnNum++ {
+	for columnNum := range indexes {
 		end := lineC.pos.x(indexes[columnNum][0])
 		delmEnd := lineC.pos.x(indexes[columnNum][1])
 		columnRanges = append(columnRanges, columnRange{start: start, end: end})
@@ -547,7 +555,7 @@ func (m Document) columnWidthRanges(lineC LineC) []columnRange {
 
 	var columnRanges []columnRange
 	start, end := 0, 0
-	for c := 0; c < len(indexes)+1; c++ {
+	for c := range len(indexes) + 1 {
 		if m.Converter == convAlign {
 			end = alignColumnEnd(lineC.lc, m.alignConv.maxWidths, c, start)
 		} else {
@@ -565,14 +573,14 @@ func (m Document) columnWidthRanges(lineC LineC) []columnRange {
 // applyColumnStyles applies the styles to the columns based on the calculated ranges.
 func (root *Root) applyColumnStyles(lineC LineC) {
 	m := root.Doc
-	numC := len(root.StyleColumnRainbow)
+	numC := len(m.Style.ColumnRainbow)
 
 	for c, colRange := range lineC.columnRanges {
 		if m.ColumnRainbow {
-			RangeStyle(lineC.lc, colRange.start, colRange.end, root.StyleColumnRainbow[c%numC])
+			RangeStyle(lineC.lc, colRange.start, colRange.end, m.Style.ColumnRainbow[c%numC])
 		}
 		if c == m.columnCursor {
-			RangeStyle(lineC.lc, colRange.start, colRange.end, root.StyleColumnHighlight)
+			RangeStyle(lineC.lc, colRange.start, colRange.end, m.Style.ColumnHighlight)
 		}
 	}
 }
@@ -596,8 +604,8 @@ func findColumnEnd(lc contents, indexes []int, n int, start int) int {
 	}
 
 	// Column overflow.
-	lCount, lPos := countToNextSpaceLeft(lc, columnEnd)
-	rCount, rPos := countToNextSpaceRight(lc, columnEnd)
+	lPos := findPrevSpace(lc, columnEnd)
+	rPos := findNextSpace(lc, columnEnd)
 
 	// Is the column omitted?
 	if lPos == columnEnd {
@@ -616,7 +624,10 @@ func findColumnEnd(lc contents, indexes []int, n int, start int) int {
 			return lPos
 		}
 	}
+
 	// It overflows on the left side.
+	lCount := columnEnd - lPos
+	rCount := rPos - columnEnd
 	if lPos > start && rCount > lCount {
 		return lPos
 	}
@@ -625,24 +636,34 @@ func findColumnEnd(lc contents, indexes []int, n int, start int) int {
 	return rPos
 }
 
-// countToNextSpaceLeft counts the number of positions to the next space character to the left.
-func countToNextSpaceLeft(lc contents, start int) (int, int) {
-	count := 0
-	i := start
-	for ; i >= 0 && !lc.IsSpace(i); i-- {
-		count++
+// findPrevSpace returns the position of the previous space.
+func findPrevSpace(lc contents, start int) int {
+	p := start
+	for {
+		if p <= 0 {
+			break
+		}
+		if lc.IsSpace(p) {
+			break
+		}
+		p--
 	}
-	return count, i
+	return p
 }
 
-// countToNextSpaceRight counts the number of positions to the next space character to the right.
-func countToNextSpaceRight(lc contents, start int) (int, int) {
-	count := 0
-	i := start
-	for ; i < len(lc) && !lc.IsSpace(i); i++ {
-		count++
+// findNextSpace returns the position of the next space.
+func findNextSpace(lc contents, start int) int {
+	p := start
+	for {
+		if p >= len(lc) {
+			break
+		}
+		if lc.IsSpace(p) {
+			break
+		}
+		p++
 	}
-	return count, i
+	return p
 }
 
 // alignColumnEnd returns the position of the end of a column.
