@@ -14,7 +14,7 @@ import (
 	"sync/atomic"
 	"unicode"
 
-	"code.rocketnine.space/tslocum/cbind"
+	"codeberg.org/tslocum/cbind"
 	"github.com/gdamore/tcell/v2"
 	"golang.org/x/sync/errgroup"
 )
@@ -174,7 +174,7 @@ func regexpCompile(r string, caseSensitive bool) *regexp.Regexp {
 	r = regexp.QuoteMeta(r)
 	re, err = regexp.Compile(r)
 	if err != nil {
-		log.Printf("regexpCompile failed %s", r)
+		log.Printf("regexpCompile failed %s:%v\n", r, err)
 		return nil
 	}
 	return re
@@ -687,7 +687,11 @@ func (root *Root) sendNextBackSearch(context.Context) {
 // This is for calling Search from the outside.
 // Normally, the event is executed from Confirm.
 func (root *Root) Search(str string) {
-	root.sendSearch(str)
+	root.Pattern = str
+	go func() {
+		root.Doc.WaitEOFWithTimeout(root.Config.ReadWaitTime)
+		root.sendSearch(str)
+	}()
 }
 
 // eventSearch represents search event.
